@@ -62,6 +62,8 @@ class LDAReducer:
                 "The passed target column doesn't exist!"
             )
 
+        # Copying the data frames.
+        self.data_frame = dataframe.copy()
         self.df = dataframe.copy()
         # Extracting X column names
         self.X_columns = [col for col in self.df.columns if col != target]
@@ -137,7 +139,7 @@ class LDAReducer:
                 raise NonNumericDataError('The given DataFrame contains non-numeric values !')
 
         # Checking if the names of the columns are different for the both dataframes.
-        if list(self.df.columns) != list(dataframe.columns):
+        if list(self.data_frame.columns) != list(dataframe.columns):
             raise DifferentColumnsError('The passed dataframe has different columns from the one passed to filter function.')
 
         # Applying the LDAs on the new data frame.
