@@ -7,6 +7,8 @@ Created with love by Sigmoid
 import numpy as np
 import matplotlib.pyplot as plt
 from sklearn.linear_model import lasso_path, LassoCV
+import pandas as pd
+from .errors import MissingDataError, NonNumericDataError, NoSuchColumnError
 def warn(*args, **kwargs):
     pass
 import warnings
@@ -32,25 +34,41 @@ class LassoSelector:
         self.extend_step = extend_step
         self.power = power
 
-    def select(self, dataframe : 'pd.DataFrame', y_column : str, cv : int = 5) -> list:
+    def select(self, dataframe : 'pd.DataFrame', target : str, cv : int = 5) -> list:
         '''
             Selecting the most important columns
         :param dataframe: pandas DataFrame
              Data Frame on which the algorithm is applied
-        :param y_column: string
+        :param target: string
              The column name of the value that we what to predict
         :param cv: integer
             Determines the cross-validation splitting strategy
         :return: list
             The list of columns selected by algorithm
         '''
+        # Checking if in the passed data are any NaN values.
+        if dataframe.isna().values.any():
+            raise MissingDataError(
+                "The passed data frame contains missing values!"
+            )
+
+        # Checking if in the passed data are non-numeric values.
+        for col in dataframe:
+            if not pd.api.types.is_numeric_dtype(dataframe[col]):
+                raise NonNumericDataError('The given DataFrame contains non-numeric values !')
+
+        # Checking if the passed target column name is present in the passed data frame.
+        if target not in dataframe:
+            raise NoSuchColumnError(
+                "The passed target column doesn't exist!"
+            )
         self.dataframe = dataframe
-        self.y_column = y_column
-        self.X_columns = [col for col in self.dataframe.columns if col != self.y_column]
+        self.target = target
+        self.X_columns = [col for col in self.dataframe.columns if col != self.target]
 
         # Converting the data frame into numpy arrays
         X = self.dataframe[self.X_columns].values
-        y = self.dataframe[self.y_column].values
+        y = self.dataframe[self.target].values
 
         # Searching for the optimal value of alpha
         while True:
@@ -88,7 +106,7 @@ class LassoSelector:
         '''
         # Converting the data frame into numpy arrays
         X = self.dataframe[self.X_columns].values
-        y = self.dataframe[self.y_column].values
+        y = self.dataframe[self.target].values
 
         # Generating the line space for the X axis
         alphas = np.linspace(self.lasso_cv.alpha_-0.1, self.lasso_cv.alpha_+0.1, self.n_alphas, endpoint=True)
