@@ -7,26 +7,22 @@ Created with love by Sigmoid
 import numpy as np
 import pandas as pd
 from math import sqrt
-from .errors import NotBetweenZeroAndOneError
+from .errors import NotBetweenZeroAndOneError, NonNumericDataError, NoSuchColumnError, MissingDataError
 class PointBiserialCorrSelector:
     def __init__(self, min_corr : float = 0.5, max_corr : float = 0.8, last_level : int = 2) -> None:
         '''
             Setting up the algorithm
         :param min_corr: float, between 0 and 1, default = 0.5
-            The minimal positive correlation value that must the feature have with y_column
+            The minimal positive correlation value that must the feature have with target
         :param max_corr: float, between 0 and 1, default = 0.8
-            The maximal positive correlation value that must the feature have with y_column
+            The maximal positive correlation value that must the feature have with target
         :param erase_corr: boolean, default = False
             If set as False the selector doesn't erase features that are highly correlated between themselves
             If set as True the selector does erase features that are highly correlated between themselves
         '''
-        try:
-            if min_corr < 0 or max_corr > 1:
-                raise NotBetweenZeroAndOneError
-        except NotBetweenZeroAndOneError:
-            print("Min or Max Correlations are not seted between 0 and 1!")
-            quit()
-        finally:
+        if min_corr < 0 or max_corr > 1 or min_corr > 1 or max_corr < 0:
+            raise NotBetweenZeroAndOneError("Min or Max Correlations are not seted between 0 and 1!")
+        else:
             self.min_corr = min_corr
             self.max_corr = max_corr
             self.last_level = last_level
@@ -65,16 +61,33 @@ class PointBiserialCorrSelector:
         # Calculating the Point-Biserial correlation
         return (Mean0 - Mean1) * sqrt((n0*n1)/n**2) / std
 
-    def select(self, dataframe : 'pd.DataFrame', y_column : str) -> list:
+    def select(self, dataframe : 'pd.DataFrame', target : str) -> list:
         '''
             Selecting the most important columns
         :param dataframe: pandas DataFrame
             Data Frame on which the algorithm is applied
-        :param y_column: string
+        :param target: string
             The column name of the value that we what to predict
         :return: list
             The list of features that are selected by the algorithm as the best one
         '''
+        # Checking if in the passed data are any NaN values.
+        if dataframe.isna().values.any():
+            raise MissingDataError(
+                "The passed data frame contains missing values!"
+            )
+
+        # Checking if in the passed data are non-numeric values.
+        for col in dataframe:
+            if not pd.api.types.is_numeric_dtype(dataframe[col]):
+                raise NonNumericDataError('The given DataFrame contains non-numeric values !')
+
+        # Checking if the passed target column name is present in the passed data frame.
+        if target not in dataframe:
+            raise NoSuchColumnError(
+                "The passed target column doesn't exist!"
+            )
+
         # Defining the empty correlation and correlation-level dictionary
         corr_dict = {}
         corr_levels = {}
@@ -87,8 +100,8 @@ class PointBiserialCorrSelector:
 
         # Calculating the point-biserial correlation for every numerical column
         for numeric_col in numeric_cols_names:
-            if numeric_col != y_column:
-                corr_dict[numeric_col] = self.pointBiserialCorr(dataframe, numeric_col, y_column)
+            if numeric_col != target:
+                corr_dict[numeric_col] = self.pointBiserialCorr(dataframe, numeric_col, target)
 
         # Placing the columns in correlation levels
         for i in range(len(bountries)-1):
